@@ -11,7 +11,7 @@
 #include <QString>
 #include <QList>
 #include <QTimer>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QFile>
 #include <QUrl>
 #ifndef NOAUDIO
@@ -53,6 +53,7 @@ class Core : public QObject
         struct CopyInstance
         {
             unsigned int id;
+            QElapsedTimer lastProgressionTime;//to compute the speed in B/s
             PluginInterface_CopyEngine * engine;
             PluginInterface_Themes * interface;
             bool ignoreMode;
@@ -73,7 +74,7 @@ class Core : public QObject
             Ultracopier::CopyType type;
             Ultracopier::TransferListOperation transferListOperation;
             bool haveError;
-            QTime lastConditionalSync;
+            QElapsedTimer lastConditionalSync;
             QTimer *nextConditionalSync;
             bool copyEngineIsSync;
             bool canceled;//to not try groun when is in canceling
@@ -124,7 +125,6 @@ class Core : public QObject
         unsigned int incrementId();
         unsigned int nextId;
         std::vector<unsigned int> idList;
-        QTime lastProgressionTime;
         QTimer forUpateInformation;///< used to call \see periodicSynchronization()
         void resetSpeedDetected(const unsigned int &bindex);
 
