@@ -311,8 +311,7 @@ void *FacilityEngine::prepareOpusAudio(const std::string &file,QBuffer &buffer)
         return nullptr;
     }
     ogg_int64_t pcm_offset;
-    ogg_int64_t nsamples;
-    nsamples=0;
+    //ogg_int64_t nsamples=0;
     pcm_offset=op_pcm_tell(of);
     if(pcm_offset!=0)
         fprintf(stderr,"Non-zero starting PCM offset: %li\n",(long)pcm_offset);
@@ -342,7 +341,7 @@ void *FacilityEngine::prepareOpusAudio(const std::string &file,QBuffer &buffer)
             out[2*si+1]=(unsigned char)(pcm[si]>>8&0xFF);
         }
         buffer.write(reinterpret_cast<char *>(out),sizeof(*out)*4*ret);
-        nsamples+=ret;
+        //nsamples+=ret;
     }
     if(ret==EXIT_SUCCESS)
         fprintf(stderr,"\nDone: played ");
