@@ -64,7 +64,7 @@ class SystrayIcon : public QSystemTrayIcon
         #endif
         QAction* actionMenuAbout;		///< Pointer on the About action
         QAction* actionOptions;			///< Pointer on the Options action
-        QAction* actionProductKey;			///< Pointer on the Options action
+        QAction* actionProductKey;			///< Pointer on the Product key action
         QIcon IconQuit;			///< Pointer on the icon for quit
         #ifdef ULTRACOPIER_DEBUG
         QIcon IconSaveBugReport;
