@@ -1,8 +1,6 @@
 /** \file QXzDecode.h
 \brief To decompress a xz stream
 \author alpha_one_x86
-\version 0.3
-\date 2010
 \licence GPL3, see the file COPYING */
 
 #ifndef QXZDECODE_H
