@@ -1,8 +1,6 @@
 /** \file QXzDecodeThread.h
 \brief To have thread to decode the data
 \author alpha_one_x86
-\version 0.3
-\date 2010
 \licence GPL3, see the file COPYING */
 
 #ifndef QXZDECODETHREAD_H
