@@ -4,91 +4,96 @@
 <context>
     <name>CopyEngine</name>
     <message>
-        <location filename="../../CopyEngine.cpp" line="438"/>
-        <location filename="../../CopyEngine.cpp" line="461"/>
+        <location filename="../../CopyEngine.cpp" line="442"/>
+        <location filename="../../CopyEngine.cpp" line="465"/>
         <source>The engine is forced to move, you can&apos;t copy with it</source>
         <translation>El motor se ve obligado a moverse, no se puede copiar con ella</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="473"/>
-        <location filename="../../CopyEngine.cpp" line="496"/>
+        <location filename="../../CopyEngine.cpp" line="519"/>
+        <location filename="../../CopyEngine.cpp" line="542"/>
         <source>The engine is forced to copy, you can&apos;t move with it</source>
         <translation>El motor se ve obligado a copiar, no te puedes mover con él</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="520"/>
+        <location filename="../../CopyEngine.cpp" line="566"/>
         <source>Destination</source>
         <translation>Destino</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="520"/>
+        <location filename="../../CopyEngine.cpp" line="566"/>
         <source>Use the actual destination &quot;%1&quot;?</source>
         <translation>Utilice el destino &quot;%1&quot; actual?</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="685"/>
+        <location filename="../../CopyEngine.cpp" line="731"/>
         <source>The mode has been forced previously. This is an internal error, please report it</source>
         <translation>El modo se ha visto obligado previamente. Este es un error interno, por favor repórtelo</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="976"/>
-        <location filename="../../CopyEngine.cpp" line="979"/>
-        <location filename="../../CopyEngine.cpp" line="984"/>
-        <location filename="../../CopyEngine.cpp" line="988"/>
+        <location filename="../../CopyEngine.cpp" line="886"/>
+        <source>Supported only on Windows</source>
+        <translation>Compatible solo con Windows</translation>
+    </message>
+    <message>
+        <location filename="../../CopyEngine.cpp" line="1035"/>
+        <location filename="../../CopyEngine.cpp" line="1038"/>
+        <location filename="../../CopyEngine.cpp" line="1043"/>
+        <location filename="../../CopyEngine.cpp" line="1047"/>
         <source>Ask</source>
         <translation>Pedir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="977"/>
-        <location filename="../../CopyEngine.cpp" line="981"/>
-        <location filename="../../CopyEngine.cpp" line="985"/>
-        <location filename="../../CopyEngine.cpp" line="989"/>
+        <location filename="../../CopyEngine.cpp" line="1036"/>
+        <location filename="../../CopyEngine.cpp" line="1040"/>
+        <location filename="../../CopyEngine.cpp" line="1044"/>
+        <location filename="../../CopyEngine.cpp" line="1048"/>
         <source>Skip</source>
         <translation>Omitir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="980"/>
+        <location filename="../../CopyEngine.cpp" line="1039"/>
         <source>Merge</source>
         <translation>Unir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="982"/>
-        <location filename="../../CopyEngine.cpp" line="994"/>
+        <location filename="../../CopyEngine.cpp" line="1041"/>
+        <location filename="../../CopyEngine.cpp" line="1053"/>
         <source>Rename</source>
         <translation>Cambiar el nombre</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="986"/>
+        <location filename="../../CopyEngine.cpp" line="1045"/>
         <source>Put at the end</source>
         <translation>Ponga al final</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="990"/>
+        <location filename="../../CopyEngine.cpp" line="1049"/>
         <source>Overwrite</source>
         <translation>Sobrescribir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="991"/>
+        <location filename="../../CopyEngine.cpp" line="1050"/>
         <source>Overwrite if different</source>
         <translation>Sobrescribir si es diferente</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="992"/>
+        <location filename="../../CopyEngine.cpp" line="1051"/>
         <source>Overwrite if newer</source>
         <translation>Sobrescribir si nuevo</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="993"/>
+        <location filename="../../CopyEngine.cpp" line="1052"/>
         <source>Overwrite if older</source>
         <translation>Sobrescribir si es mayor</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="1064"/>
+        <location filename="../../CopyEngine.cpp" line="1123"/>
         <source>Options error</source>
         <translation>error Opciones</translation>
     </message>
     <message>
-        <location filename="../../CopyEngine.cpp" line="1064"/>
+        <location filename="../../CopyEngine.cpp" line="1123"/>
         <source>Options engine is not loaded. Unable to access the filters</source>
         <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
     </message>
@@ -96,75 +101,76 @@
 <context>
     <name>CopyEngineFactory</name>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="303"/>
+        <location filename="../../CopyEngineFactory.cpp" line="60"/>
+        <location filename="../../CopyEngineFactory.cpp" line="309"/>
         <source>Supported only on Windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Compatible solo con Windows</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="430"/>
-        <location filename="../../CopyEngineFactory.cpp" line="433"/>
-        <location filename="../../CopyEngineFactory.cpp" line="438"/>
-        <location filename="../../CopyEngineFactory.cpp" line="442"/>
+        <location filename="../../CopyEngineFactory.cpp" line="436"/>
+        <location filename="../../CopyEngineFactory.cpp" line="439"/>
+        <location filename="../../CopyEngineFactory.cpp" line="444"/>
+        <location filename="../../CopyEngineFactory.cpp" line="448"/>
         <source>Ask</source>
         <translation>Pedir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="431"/>
-        <location filename="../../CopyEngineFactory.cpp" line="435"/>
-        <location filename="../../CopyEngineFactory.cpp" line="439"/>
-        <location filename="../../CopyEngineFactory.cpp" line="443"/>
+        <location filename="../../CopyEngineFactory.cpp" line="437"/>
+        <location filename="../../CopyEngineFactory.cpp" line="441"/>
+        <location filename="../../CopyEngineFactory.cpp" line="445"/>
+        <location filename="../../CopyEngineFactory.cpp" line="449"/>
         <source>Skip</source>
         <translation>Omitir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="434"/>
+        <location filename="../../CopyEngineFactory.cpp" line="440"/>
         <source>Merge</source>
         <translation>Unir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="436"/>
-        <location filename="../../CopyEngineFactory.cpp" line="448"/>
+        <location filename="../../CopyEngineFactory.cpp" line="442"/>
+        <location filename="../../CopyEngineFactory.cpp" line="454"/>
         <source>Rename</source>
         <translation>Cambiar el nombre</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="440"/>
+        <location filename="../../CopyEngineFactory.cpp" line="446"/>
         <source>Put at the end</source>
         <translation>Ponga al final</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="444"/>
+        <location filename="../../CopyEngineFactory.cpp" line="450"/>
         <source>Overwrite</source>
         <translation>Sobrescribir</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="445"/>
+        <location filename="../../CopyEngineFactory.cpp" line="451"/>
         <source>Overwrite if different</source>
         <translation>Sobrescribir si es diferente</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="446"/>
+        <location filename="../../CopyEngineFactory.cpp" line="452"/>
         <source>Overwrite if newer</source>
         <translation>Sobrescribir si nuevo</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="447"/>
+        <location filename="../../CopyEngineFactory.cpp" line="453"/>
         <source>Overwrite if older</source>
         <translation>Sobrescribir si es mayor</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="463"/>
-        <location filename="../../CopyEngineFactory.cpp" line="502"/>
+        <location filename="../../CopyEngineFactory.cpp" line="469"/>
+        <location filename="../../CopyEngineFactory.cpp" line="508"/>
         <source>Options error</source>
         <translation>error Opciones</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="463"/>
+        <location filename="../../CopyEngineFactory.cpp" line="469"/>
         <source>Options engine is not loaded. Unable to access the filters</source>
         <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
     </message>
     <message>
-        <location filename="../../CopyEngineFactory.cpp" line="502"/>
+        <location filename="../../CopyEngineFactory.cpp" line="508"/>
         <source>Options engine is not loaded, can&apos;t access to the filters</source>
         <translation>Opciones del motor no está cargado, no se puede acceder a los filtros</translation>
     </message>
@@ -200,12 +206,12 @@
 <context>
     <name>FileErrorDialog</name>
     <message>
-        <location filename="../../FileErrorDialog.cpp" line="87"/>
+        <location filename="../../FileErrorDialog.cpp" line="92"/>
         <source>Error on folder</source>
         <translation>Error en la carpeta</translation>
     </message>
     <message>
-        <location filename="../../FileErrorDialog.cpp" line="90"/>
+        <location filename="../../FileErrorDialog.cpp" line="95"/>
         <source>Folder name</source>
         <translation>Nombre de la carpeta</translation>
     </message>
@@ -213,22 +219,22 @@
 <context>
     <name>FileExistsDialog</name>
     <message>
-        <location filename="../../FileExistsDialog.cpp" line="191"/>
+        <location filename="../../FileExistsDialog.cpp" line="201"/>
         <source>%name% - copy%suffix%</source>
         <translation>%name% - copia%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FileExistsDialog.cpp" line="198"/>
+        <location filename="../../FileExistsDialog.cpp" line="208"/>
         <source>%name% - copy (%number%)%suffix%</source>
         <translation>%name% - copia (%number%)%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FileExistsDialog.cpp" line="289"/>
+        <location filename="../../FileExistsDialog.cpp" line="299"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../../FileExistsDialog.cpp" line="289"/>
+        <location filename="../../FileExistsDialog.cpp" line="299"/>
         <source>Try rename with using special characters</source>
         <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
     </message>
@@ -236,22 +242,22 @@
 <context>
     <name>FileIsSameDialog</name>
     <message>
-        <location filename="../../FileIsSameDialog.cpp" line="140"/>
+        <location filename="../../FileIsSameDialog.cpp" line="145"/>
         <source>%name% - copy%suffix%</source>
         <translation>%name% - copia%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FileIsSameDialog.cpp" line="147"/>
+        <location filename="../../FileIsSameDialog.cpp" line="152"/>
         <source>%name% - copy (%number%)%suffix%</source>
         <translation>%name% - copia (%number%)%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FileIsSameDialog.cpp" line="220"/>
+        <location filename="../../FileIsSameDialog.cpp" line="225"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../../FileIsSameDialog.cpp" line="220"/>
+        <location filename="../../FileIsSameDialog.cpp" line="225"/>
         <source>Try rename with using special characters</source>
         <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
     </message>
@@ -398,27 +404,27 @@
 <context>
     <name>FolderExistsDialog</name>
     <message>
-        <location filename="../../FolderExistsDialog.cpp" line="84"/>
+        <location filename="../../FolderExistsDialog.cpp" line="91"/>
         <source>Folder already exists</source>
         <translation>Carpeta ya existe</translation>
     </message>
     <message>
-        <location filename="../../FolderExistsDialog.cpp" line="164"/>
+        <location filename="../../FolderExistsDialog.cpp" line="172"/>
         <source>%name% - copy%suffix%</source>
         <translation>%name% - copia%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FolderExistsDialog.cpp" line="173"/>
+        <location filename="../../FolderExistsDialog.cpp" line="181"/>
         <source>%name% - copy (%number%)%suffix%</source>
         <translation>%name% - copia (%number%)%suffix%</translation>
     </message>
     <message>
-        <location filename="../../FolderExistsDialog.cpp" line="240"/>
+        <location filename="../../FolderExistsDialog.cpp" line="248"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../../FolderExistsDialog.cpp" line="240"/>
+        <location filename="../../FolderExistsDialog.cpp" line="248"/>
         <source>Try rename with using special characters</source>
         <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
     </message>
@@ -478,6 +484,8 @@
     <message>
         <location filename="../../MkPath.cpp" line="187"/>
         <location filename="../../MkPath.cpp" line="210"/>
+        <location filename="../../MkPath.cpp" line="315"/>
+        <location filename="../../MkPath.cpp" line="363"/>
         <source>Unable to create the folder</source>
         <translation>No se puede crear la carpeta</translation>
     </message>
@@ -487,28 +495,33 @@
         <translation>La carpeta de origen no existe</translation>
     </message>
     <message>
-        <location filename="../../MkPath.cpp" line="255"/>
+        <location filename="../../MkPath.cpp" line="304"/>
         <source>Unable to temporary rename the folder</source>
         <translation>No es posible cambiar el nombre de la carpeta temporal</translation>
     </message>
     <message>
-        <location filename="../../MkPath.cpp" line="278"/>
+        <location filename="../../MkPath.cpp" line="339"/>
+        <source>Unable to reverse temporary rename for real move</source>
+        <translation>No se puede revertir el cambio de nombre temporal para un movimiento real</translation>
+    </message>
+    <message>
+        <location filename="../../MkPath.cpp" line="348"/>
         <source>Unable to do the final real move the folder</source>
         <translation>No se puede hacer el movimiento final real de la carpeta</translation>
     </message>
     <message>
-        <location filename="../../MkPath.cpp" line="309"/>
+        <location filename="../../MkPath.cpp" line="379"/>
         <source>Unable to move the folder</source>
         <translation>No se puede mover la carpeta</translation>
     </message>
     <message>
-        <location filename="../../MkPath.cpp" line="315"/>
+        <location filename="../../MkPath.cpp" line="385"/>
         <source>Unable to move the folder: errno: %1</source>
         <translation>No se puede mover la carpeta: errno: %1</translation>
     </message>
     <message>
         <location filename="../../MkPath.cpp" line="124"/>
-        <location filename="../../MkPath.cpp" line="394"/>
+        <location filename="../../MkPath.cpp" line="464"/>
         <source>Unable to remove</source>
         <translation>No se puede eliminar</translation>
     </message>
@@ -521,12 +534,12 @@
         <translation>¡Error interno, por favor repórtelo!</translation>
     </message>
     <message>
-        <location filename="../../async/ReadThread.cpp" line="541"/>
+        <location filename="../../async/ReadThread.cpp" line="543"/>
         <source>Unable to read the source file: </source>
         <translation>No se puede leer el archivo fuente: </translation>
     </message>
     <message>
-        <location filename="../../async/ReadThread.cpp" line="595"/>
+        <location filename="../../async/ReadThread.cpp" line="599"/>
         <source>File truncated during the read, possible data change</source>
         <translation>Archivo truncado durante la lectura, posible cambio de datos</translation>
     </message>
@@ -582,32 +595,38 @@
 <context>
     <name>ScanFileOrFolder</name>
     <message>
-        <location filename="../../ScanFileOrFolder.cpp" line="452"/>
-        <location filename="../../ScanFileOrFolder.cpp" line="454"/>
-        <source>%1 - copy</source>
-        <translation>%1 - copia</translation>
+        <location filename="../../ScanFileOrFolder.cpp" line="331"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="681"/>
+        <source>Blacklisted folder</source>
+        <translation>Carpeta en la lista negra</translation>
     </message>
     <message>
         <location filename="../../ScanFileOrFolder.cpp" line="463"/>
         <location filename="../../ScanFileOrFolder.cpp" line="465"/>
+        <source>%1 - copy</source>
+        <translation>%1 - copia</translation>
+    </message>
+    <message>
+        <location filename="../../ScanFileOrFolder.cpp" line="474"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="476"/>
         <source>%1 - copy (%2)</source>
         <translation>%1 - copia (%2)</translation>
     </message>
     <message>
-        <location filename="../../ScanFileOrFolder.cpp" line="576"/>
-        <location filename="../../ScanFileOrFolder.cpp" line="578"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
         <source>%name% - copy</source>
         <translation>%name% - copia</translation>
     </message>
     <message>
-        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
-        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="598"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="600"/>
         <source>%name% - copy (%number%)</source>
         <translation>%name% - copia (%number%)</translation>
     </message>
     <message>
-        <location filename="../../ScanFileOrFolder.cpp" line="673"/>
-        <location filename="../../ScanFileOrFolder.cpp" line="677"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="691"/>
+        <location filename="../../ScanFileOrFolder.cpp" line="695"/>
         <source>Problem with folder read</source>
         <translation>Problema con la carpeta leída</translation>
     </message>
@@ -615,29 +634,29 @@
 <context>
     <name>TransferThread</name>
     <message>
-        <location filename="../../TransferThread.cpp" line="613"/>
+        <location filename="../../TransferThread.cpp" line="628"/>
         <source>%name% - copy%suffix%</source>
         <translation>%name% - copia%suffix%</translation>
     </message>
     <message>
-        <location filename="../../TransferThread.cpp" line="620"/>
+        <location filename="../../TransferThread.cpp" line="635"/>
         <source>%name% - copy (%number%)%suffix%</source>
         <translation>%name% - copia (%number%)%suffix%</translation>
     </message>
     <message>
-        <location filename="../../TransferThread.cpp" line="648"/>
-        <location filename="../../TransferThread.cpp" line="889"/>
+        <location filename="../../TransferThread.cpp" line="663"/>
+        <location filename="../../TransferThread.cpp" line="904"/>
         <source>File not found</source>
         <translation>Archivo no encontrado</translation>
     </message>
     <message>
-        <location filename="../../TransferThread.cpp" line="889"/>
-        <location filename="../../TransferThread.cpp" line="925"/>
+        <location filename="../../TransferThread.cpp" line="904"/>
+        <location filename="../../TransferThread.cpp" line="940"/>
         <source>Unable to change the date</source>
         <translation>No se puede cambiar la fecha</translation>
     </message>
     <message>
-        <location filename="../../TransferThread.cpp" line="179"/>
+        <location filename="../../TransferThread.cpp" line="188"/>
         <source>Try rename with using special characters</source>
         <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
     </message>
@@ -645,19 +664,19 @@
 <context>
     <name>TransferThreadAsync</name>
     <message>
-        <location filename="../../async/TransferThreadAsync.cpp" line="340"/>
+        <location filename="../../async/TransferThreadAsync.cpp" line="342"/>
         <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
         <translation>Fecha de modificación incorrecta o incapaz de obtenerla, puede desactivar la transferencia de tiempo para hacerlo</translation>
     </message>
     <message>
-        <location filename="../../async/TransferThreadAsync.cpp" line="428"/>
-        <location filename="../../async/TransferThreadAsync.cpp" line="446"/>
+        <location filename="../../async/TransferThreadAsync.cpp" line="436"/>
+        <location filename="../../async/TransferThreadAsync.cpp" line="454"/>
         <source>Unable to create the destination folder: </source>
         <translation>No se puede crear la carpeta de destino: </translation>
     </message>
     <message>
-        <location filename="../../async/TransferThreadAsync.cpp" line="431"/>
-        <location filename="../../async/TransferThreadAsync.cpp" line="448"/>
+        <location filename="../../async/TransferThreadAsync.cpp" line="439"/>
+        <location filename="../../async/TransferThreadAsync.cpp" line="456"/>
         <source>Unable to create the destination folder, errno: %1</source>
         <translation>No se puede crear la carpeta de destino, errno: %1</translation>
     </message>
@@ -665,24 +684,24 @@
 <context>
     <name>WriteThread</name>
     <message>
-        <location filename="../../async/WriteThread.cpp" line="135"/>
+        <location filename="../../async/WriteThread.cpp" line="138"/>
         <source>Path resolution error (Empty path)</source>
         <translation>Error de resolución de ruta (ruta vacía)</translation>
     </message>
     <message>
-        <location filename="../../async/WriteThread.cpp" line="164"/>
-        <location filename="../../async/WriteThread.cpp" line="197"/>
+        <location filename="../../async/WriteThread.cpp" line="167"/>
+        <location filename="../../async/WriteThread.cpp" line="200"/>
         <source>Unable to create the destination folder: </source>
         <translation>No se puede crear la carpeta de destino: </translation>
     </message>
     <message>
-        <location filename="../../async/WriteThread.cpp" line="175"/>
-        <location filename="../../async/WriteThread.cpp" line="199"/>
+        <location filename="../../async/WriteThread.cpp" line="178"/>
+        <location filename="../../async/WriteThread.cpp" line="202"/>
         <source>Unable to create the destination folder, errno: %1</source>
         <translation>No se puede crear la carpeta de destino, errno: %1</translation>
     </message>
     <message>
-        <location filename="../../async/WriteThread.cpp" line="456"/>
+        <location filename="../../async/WriteThread.cpp" line="464"/>
         <source>Internal error, please report it!</source>
         <translation>¡Error interno, por favor repórtelo!</translation>
     </message>
@@ -793,7 +812,7 @@
         <location filename="../../copyEngineOptions.ui" line="397"/>
         <location filename="../../copyEngineOptions.ui" line="413"/>
         <source>MB</source>
-        <translation type="unfinished"></translation>
+        <translation>MB</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="429"/>
@@ -803,32 +822,32 @@
     <message>
         <location filename="../../copyEngineOptions.ui" line="436"/>
         <source>OS Buffer</source>
-        <translation type="unfinished"></translation>
+        <translation>Búfer del SO</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="456"/>
         <source>Disable parallel transfer when are different devices</source>
-        <translation type="unfinished"></translation>
+        <translation>Deshabilitar la transferencia paralela cuando hay diferentes dispositivos</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="463"/>
         <source>Buffer for different device</source>
-        <translation type="unfinished"></translation>
+        <translation>Búfer para diferentes dispositivos</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="470"/>
         <source>OS FLags</source>
-        <translation type="unfinished"></translation>
+        <translation>Banderas de SO</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="477"/>
         <source>Buffer for same device</source>
-        <translation type="unfinished"></translation>
+        <translation>Búfer para el mismo dispositivo</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="484"/>
         <source>OS native copy (disable speed limitation)</source>
-        <translation type="unfinished"></translation>
+        <translation>Copia nativa del sistema operativo (deshabilitar la limitación de velocidad)</translation>
     </message>
     <message>
         <location filename="../../copyEngineOptions.ui" line="514"/>
@@ -975,12 +994,27 @@
         <source>&amp;Always perform this action</source>
         <translation>&amp;Siempre realice esta acción</translation>
     </message>
+    <message>
+        <location filename="../../fileExistsDialog.ui" line="341"/>
+        <source>Overwrite if source newer than destination</source>
+        <translation>Sobrescribir si la fuente es más nueva que el destino</translation>
+    </message>
     <message>
         <location filename="../../fileExistsDialog.ui" line="346"/>
         <location filename="../../fileExistsDialog.ui" line="349"/>
         <source>Overwrite if modification date differs</source>
         <translation>Sobrescribir si la fecha de modificación difiere</translation>
     </message>
+    <message>
+        <location filename="../../fileExistsDialog.ui" line="354"/>
+        <source>Overwrite if source older than destination</source>
+        <translation>Sobrescribir si la fuente es más antigua que el destino</translation>
+    </message>
+    <message>
+        <location filename="../../fileExistsDialog.ui" line="357"/>
+        <source>Overwrite if destination older</source>
+        <translation>Sobrescribir si el destino es más antiguo</translation>
+    </message>
     <message>
         <location filename="../../fileExistsDialog.ui" line="362"/>
         <location filename="../../fileExistsDialog.ui" line="365"/>
@@ -1013,17 +1047,6 @@
         <source>&amp;Cancel</source>
         <translation>Ca&amp;ncelar</translation>
     </message>
-    <message>
-        <location filename="../../fileExistsDialog.ui" line="341"/>
-        <source>Overwrite if newer</source>
-        <translation>Sobrescribir si nuevo</translation>
-    </message>
-    <message>
-        <location filename="../../fileExistsDialog.ui" line="354"/>
-        <location filename="../../fileExistsDialog.ui" line="357"/>
-        <source>Overwrite if older</source>
-        <translation>Sobrescribir si es mayor</translation>
-    </message>
 </context>
 <context>
     <name>fileIsSameDialog</name>
