@@ -166,7 +166,23 @@ void ListThread::transferInodeIsClosed()
     {
         if(actionToDoListTransfer.at(int_for_internal_loop).id==temp_transfer_thread->transferId)
         {
-            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,QStringLiteral("[%1] have finish, put at idle; for id: %2").arg(int_for_internal_loop).arg(temp_transfer_thread->transferId).toStdString());
+            #ifdef ULTRACOPIER_PLUGIN_DEBUG
+            std::string threadidstring="?";
+            {
+                size_t index=0;
+                while(index<transferThreadList.size())
+                {
+                    if(transferThreadList.at(index)==temp_transfer_thread)
+                    {
+                        threadidstring=std::to_string(index);
+                        break;
+                    }
+                    index++;
+                }
+            }
+            #endif
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,QStringLiteral("[%1] have finish, put at idle; for id: %2").arg(QString::fromStdString(threadidstring))
+                                     .arg(temp_transfer_thread->transferId).toStdString()+" "+TransferThread::internalStringTostring(temp_transfer_thread->getDestinationPath()));
             Ultracopier::ReturnActionOnCopyList newAction;
             newAction.type=Ultracopier::RemoveItem;
             newAction.userAction.moveAt=0;
@@ -196,6 +212,8 @@ void ListThread::transferInodeIsClosed()
             }
             bytesTransfered+=temp_transfer_thread->transferSize;
 
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+threadidstring+"] transferId=0 currentTransferThread->transferId: "+
+                                     std::to_string(temp_transfer_thread->transferId)+" on thread "+std::to_string((quint64)QThread::currentThread()));
             temp_transfer_thread->transferId=0;
             temp_transfer_thread->transferSize=0;
             #ifdef ULTRACOPIER_PLUGIN_DEBUG
@@ -215,7 +233,9 @@ void ListThread::transferInodeIsClosed()
         int_for_internal_loop++;
     }
     if(isFound)
-        deleteTransferThread();
+    {
+        //deleteTransferThread();//why? generate use after free!
+    }
     else
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,QStringLiteral("unable to found item into the todo list, id: %1, index: %2").arg(temp_transfer_thread->transferId).arg(int_for_internal_loop).toStdString());
@@ -271,6 +291,24 @@ void ListThread::transferPutAtBottom()
             //move at the end
             actionToDoListTransfer.push_back(actionToDoListTransfer.at(indexAction));
             actionToDoListTransfer.erase(actionToDoListTransfer.cbegin()+indexAction);
+            #ifdef ULTRACOPIER_PLUGIN_DEBUG
+            {
+                size_t index=0;
+                while(index<transferThreadList.size())
+                {
+                    if(transferThreadList.at(index)==transfer)
+                    {
+                        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(index)+"] currentTransferThread->transferId: "+
+                                             std::to_string(transfer->transferId)+" on thread "+std::to_string((quint64)QThread::currentThread()));
+                        break;
+                    }
+                    index++;
+                }
+                if(index>=transferThreadList.size())
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"[?] currentTransferThread->transferId: "+
+                                     std::to_string(transfer->transferId)+" on thread "+std::to_string((quint64)QThread::currentThread()));
+            }
+            #endif
             transfer->transferId=0;
             transfer->transferSize=0;
             #ifdef ULTRACOPIER_PLUGIN_DEBUG
@@ -301,6 +339,13 @@ void ListThread::fileTransfer(const INTERNALTYPEPATH &sourceFileInfo,const INTER
 {
     if(stopIt)
         return;
+    #ifdef Q_OS_WIN32
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"source: "+TransferThread::internalStringTostring(sourceFileInfo)+
+                             ", destination: "+TransferThread::internalStringTostring(destinationFileInfo)+" windows");
+    #else
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"source: "+TransferThread::internalStringTostring(sourceFileInfo)+
+                             ", destination: "+TransferThread::internalStringTostring(destinationFileInfo)+" unix");
+    #endif
     addToTransfer(sourceFileInfo,destinationFileInfo,mode);
 }
 
@@ -310,9 +355,13 @@ void ListThread::fileTransferWithInode(const INTERNALTYPEPATH &sourceFileInfo,co
     if(stopIt)
         return;
     #ifdef Q_OS_WIN32
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"source: "+TransferThread::internalStringTostring(sourceFileInfo)+
+                             ", destination: "+TransferThread::internalStringTostring(destinationFileInfo)+" windows "+std::to_string(inode.isFolder));
     addToTransfer(sourceFileInfo,destinationFileInfo,mode,inode.size);
     #else
     (void)inode;
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"source: "+TransferThread::internalStringTostring(sourceFileInfo)+
+                             ", destination: "+TransferThread::internalStringTostring(destinationFileInfo)+" unix");
     addToTransfer(sourceFileInfo,destinationFileInfo,mode);
     #endif
 }
@@ -642,6 +691,13 @@ uint64_t ListThread::addToTransfer(const INTERNALTYPEPATH &source, const INTERNA
         const int64_t tempSize=TransferThread::file_stat_size(source);
         if(tempSize>=0)
             size=tempSize;
+        else
+        {
+            if(TransferThread::is_file(source))
+                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"Unable to detect size on "+TransferThread::internalStringTostring(source));
+            else
+                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"File not existing during listing "+TransferThread::internalStringTostring(source));
+        }
     }
     const std::string &drive=driveManagement.getDrive(TransferThread::internalStringTostring(destination));
     if(!drive.empty())//can be a network drive
@@ -850,6 +906,24 @@ void ListThread::doNewActions_inode_manipulation()
                 if(currentTransferThread->getStat()==TransferStat_Idle && currentTransferThread->transferId==0 &&
                         overCheckUsedThread.find(currentTransferThread)==overCheckUsedThread.cend()) // /!\ important!
                 {
+                    #ifdef ULTRACOPIER_PLUGIN_DEBUG
+                    {
+                        size_t index=0;
+                        while(index<transferThreadList.size())
+                        {
+                            if(transferThreadList.at(index)==currentTransferThread)
+                            {
+                                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(index)+"] currentTransferThread->transferId: "+
+                                                     std::to_string(currentTransferThread->transferId)+" on thread "+std::to_string((quint64)QThread::currentThread()));
+                                break;
+                            }
+                            index++;
+                        }
+                        if(index>=transferThreadList.size())
+                            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"[?] currentTransferThread->transferId: "+
+                                             std::to_string(currentTransferThread->transferId)+" on thread "+std::to_string((quint64)QThread::currentThread()));
+                    }
+                    #endif
                     overCheckUsedThread.insert(currentTransferThread);
 
                     std::string drive=driveManagement.getDrive(TransferThread::internalStringTostring(currentActionToDoTransfer.destination));
@@ -871,12 +945,19 @@ void ListThread::doNewActions_inode_manipulation()
                         currentActionToDoTransfer.mode
                         ))
                     {
-                        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(int_for_loop)+"] id: "+
+                        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"["+std::to_string(int_for_loop)+"] id: "+
                                                  std::to_string(currentTransferThread->transferId)+
                                                  " is idle, but seam busy at set name: "+TransferThread::internalStringTostring(currentActionToDoTransfer.destination)
                                                  );
                         break;
                     }
+                    else
+                    {
+                        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(int_for_loop)+"] id: "+
+                                                 std::to_string(currentTransferThread->transferId)+
+                                                 " is idle, but seam busy at set name: "+TransferThread::internalStringTostring(currentActionToDoTransfer.destination)
+                                                 );
+                    }
                     currentActionToDoTransfer.isRunning=true;
 
                     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(int_for_loop)+"] id: "+
@@ -1063,12 +1144,14 @@ void ListThread::mkPathFirstFolderFinish()
 /// \note Can be call without queue because all call will be serialized
 void ListThread::fileAlreadyExists(const INTERNALTYPEPATH &source,const INTERNALTYPEPATH &destination,const bool &isSame)
 {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,TransferThread::internalStringTostring(source)+" to "+TransferThread::internalStringTostring(destination));
     emit send_fileAlreadyExists(source,destination,isSame,qobject_cast<TransferThreadAsync *>(sender()));
 }
 
 /// \note Can be call without queue because all call will be serialized
 void ListThread::errorOnFile(const INTERNALTYPEPATH &fileInfo, const std::string &errorString, const ErrorType &errorType)
 {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,TransferThread::internalStringTostring(fileInfo)+" error: "+errorString);
     TransferThreadAsync * transferThread=qobject_cast<TransferThreadAsync *>(sender());
     if(transferThread==NULL)
     {
@@ -1090,6 +1173,7 @@ void ListThread::errorOnFile(const INTERNALTYPEPATH &fileInfo, const std::string
 /// \note Can be call without queue because all call will be serialized
 void ListThread::folderAlreadyExists(const INTERNALTYPEPATH &source,const INTERNALTYPEPATH &destination,const bool &isSame)
 {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,TransferThread::internalStringTostring(source)+" to "+TransferThread::internalStringTostring(destination));
     emit send_folderAlreadyExists(source,destination,isSame,qobject_cast<ScanFileOrFolder *>(sender()));
 }
 
@@ -1097,6 +1181,7 @@ void ListThread::folderAlreadyExists(const INTERNALTYPEPATH &source,const INTERN
 /// \todo all this part
 void ListThread::errorOnFolder(const INTERNALTYPEPATH &fileInfo,const std::string &errorString,const ErrorType &errorType)
 {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,TransferThread::internalStringTostring(fileInfo)+" error: "+errorString);
     emit send_errorOnFolder(fileInfo,errorString,qobject_cast<ScanFileOrFolder *>(sender()),errorType);
 }
 
@@ -1121,6 +1206,7 @@ void ListThread::getNeedPutAtBottom(const INTERNALTYPEPATH &fileInfo, const std:
 /// \to create transfer thread
 void ListThread::createTransferThread()
 {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"start");
     if(stopIt)
         return;
     if(transferThreadList.size()>=(unsigned int)inodeThreads)
@@ -1206,6 +1292,7 @@ void ListThread::deleteTransferThread()
         int index=0;
         while(index<loop_size && loop_size>inodeThreads)
         {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"delete thread ["+std::to_string(index)+"]");
             if(transferThreadList.at(index)->getStat()==TransferStat_Idle && transferThreadList.at(index)->transferId==0)
             {
                 transferThreadList.at(index)->stop();
