@@ -93,6 +93,10 @@ void TransferThread::run()
     if(!connect(&driveManagement,&DriveManagement::debugInformation,this,                   &TransferThread::debugInformation,	Qt::QueuedConnection))
         abort();
     #endif
+    if(!connect(this,&TransferThread::setFileRenameSend,this,                   &TransferThread::setFileRenameInternal,	Qt::QueuedConnection))
+        abort();
+    if(!connect(this,&TransferThread::setAlwaysFileExistsActionSend,this,                   &TransferThread::setAlwaysFileExistsActionInternal,	Qt::QueuedConnection))
+        abort();
 }
 
 TransferStat TransferThread::getStat() const
@@ -166,6 +170,11 @@ bool TransferThread::setFiles(const INTERNALTYPEPATH& source, const int64_t &siz
 }
 
 void TransferThread::setFileRename(const std::string &nameForRename)
+{
+    emit setFileRenameSend(nameForRename);
+}
+
+void TransferThread::setFileRenameInternal(const std::string &nameForRename)
 {
     if(transfer_stat!=TransferStat_PreOperation)
     {
@@ -256,6 +265,11 @@ bool TransferThread::rename(const INTERNALTYPEPATH &source, const INTERNALTYPEPA
 }
 
 void TransferThread::setAlwaysFileExistsAction(const FileExistsAction &action)
+{
+    emit setAlwaysFileExistsActionSend(action);
+}
+
+void TransferThread::setAlwaysFileExistsActionInternal(const FileExistsAction &action)
 {
     //ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+QStringLiteral("] action to do always: ")+QString::number(action)));
     alwaysDoFileExistsAction=action;
@@ -297,6 +311,7 @@ bool TransferThread::isSame()
         }
         if(checkAlwaysRename())
             return false;
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,internalStringTostring(source)+" to "+internalStringTostring(destination));
         emit fileAlreadyExists(source,destination,true);
         return true;
     }
@@ -771,7 +786,7 @@ bool TransferThread::mkpath(const INTERNALTYPEPATH &path)
             return false;
         #endif
 
-	pathCedit.resize(lastpos);
+        pathCedit.resize(lastpos);
         previouspos=lastpos;
 
         errno=0;
@@ -981,12 +996,13 @@ int64_t TransferThread::readFileMDateTime(const INTERNALTYPEPATH &source)
                 return -1;
             }
             CloseHandle(hFileSouce);
-            const int64_t UNIX_TIME_START = 0x019DB1DED53E8000; //January 1, 1970 (start of Unix epoch) in "ticks"
-            const int64_t TICKS_PER_SECOND = 10000000; //a tick is 100ns
+            //const int64_t UNIX_TIME_START = 0x019DB1DED53E8000; //January 1, 1970 (start of Unix epoch) in "ticks"
+            //const int64_t TICKS_PER_SECOND = 10000000; //a tick is 100ns
             LARGE_INTEGER li;
             li.LowPart  = ftWrite.dwLowDateTime;
             li.HighPart = ftWrite.dwHighDateTime;
-            return (li.QuadPart - UNIX_TIME_START) / TICKS_PER_SECOND;
+            //return (li.QuadPart - UNIX_TIME_START) / TICKS_PER_SECOND;
+            return (li.QuadPart - 0x019DB1DED53E8000) / 10000000;
         #else
             return -1;
         #endif
@@ -1044,7 +1060,10 @@ bool TransferThread::readSourceFileDateTime(const INTERNALTYPEPATH &source)
             this->ftAccess=ftAccess;
             this->ftWrite=ftWrite;
             CloseHandle(hFileSouce);
-            const uint64_t modtime=(uint64_t)ftWrite.dwLowDateTime + ((uint64_t)2^32 * (uint64_t)ftWrite.dwHighDateTime);
+            LARGE_INTEGER li;
+            li.LowPart  = ftWrite.dwLowDateTime;
+            li.HighPart = ftWrite.dwHighDateTime;
+            const uint64_t modtime=(li.QuadPart - 0x019DB1DED53E8000) / 10000000;
             if(modtime<ULTRACOPIER_PLUGIN_MINIMALYEAR_TIMESTAMPS)
             {
                 //ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"["+std::to_string(id)+"] the sources is older to copy the time: "+source+": "+source.lastModified().toString().toStdString());
@@ -1250,7 +1269,8 @@ bool TransferThread::is_file(const char * const filename)
     #ifdef Q_OS_WIN32
     DWORD dwAttrib = GetFileAttributesA(TransferThread::toFinalPath(filename).c_str());
     return (dwAttrib != INVALID_FILE_ATTRIBUTES &&
-           (dwAttrib & FILE_ATTRIBUTE_DIRECTORY));
+           (dwAttrib & FILE_ATTRIBUTE_NORMAL || dwAttrib & FILE_ATTRIBUTE_ARCHIVE)
+            );
     #else
     struct stat p_statbuf;
     if (lstat(filename, &p_statbuf) < 0)
