@@ -112,15 +112,9 @@ TransferThreadAsync::TransferThreadAsync() :
     if(!connect(&writeThread,&WriteThread::opened,                  this,					&TransferThreadAsync::write_opened,         Qt::QueuedConnection))
         abort();
 
-    //error management
-/*    if(!connect(&readThread,&ReadThread::isSeekToZeroAndWait,       this,					&TransferThreadAsync::readThreadIsSeekToZeroAndWait,	Qt::QueuedConnection))
-        abort();
-    if(!connect(&readThread,&ReadThread::resumeAfterErrorByRestartAtTheLastPosition,this,	&TransferThreadAsync::readThreadResumeAfterError,	Qt::QueuedConnection))
-        abort();
+    //error management, just try restart from 0
     if(!connect(&readThread,&ReadThread::resumeAfterErrorByRestartAll,&writeThread,         &WriteThread::flushAndSeekToZero,               Qt::QueuedConnection))
         abort();
-    if(!connect(&writeThread,&WriteThread::flushedAndSeekedToZero,  this,                   &TransferThread::readThreadResumeAfterError,	Qt::QueuedConnection))
-        abort();*/
 
     #ifdef ULTRACOPIER_PLUGIN_DEBUG
     if(!connect(&readThread,&ReadThread::debugInformation,          this,                   &TransferThreadAsync::debugInformation,  Qt::QueuedConnection))
@@ -130,6 +124,8 @@ TransferThreadAsync::TransferThreadAsync() :
     if(!connect(&driveManagement,&DriveManagement::debugInformation,this,                   &TransferThreadAsync::debugInformation,	Qt::QueuedConnection))
         abort();
     #endif
+    if(!connect(this,&TransferThreadAsync::setFileExistsActionSend,this,                   &TransferThreadAsync::setFileExistsActionInternal,	Qt::QueuedConnection))
+        abort();
 
     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] start: "+std::to_string((int64_t)QThread::currentThreadId()));
     start();
@@ -177,7 +173,7 @@ void TransferThreadAsync::run()
 
 void TransferThreadAsync::startTheTransfer()
 {
-    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start"));
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start")+", transfert id: "+std::to_string(transferId));
     if(transferId==0)
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] can't start transfert if transferId==0"));
@@ -194,7 +190,7 @@ void TransferThreadAsync::internalStartTheTransfer()
     if(QThread::currentThread()!=this)
         abort();
     #endif
-    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start"));
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start")+", transfert id: "+std::to_string(transferId)+" readError: "+std::to_string(writeError)+" writeError: "+std::to_string(writeError)+" canStartTransfer: "+std::to_string(canStartTransfer));
     if(transfer_stat==TransferStat_Idle)
     {
         if(mode!=Ultracopier::Move)
@@ -204,25 +200,25 @@ void TransferThreadAsync::internalStartTheTransfer()
         }
         return;
     }
-    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start"));
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start")+", transfert id: "+std::to_string(transferId));
     if(transfer_stat==TransferStat_PostOperation)
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] can't start transfert at PostOperation"));
         return;
     }
-    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start"));
-    if(transfer_stat==TransferStat_Transfer)
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start")+", transfert id: "+std::to_string(transferId));
+    if(transfer_stat==TransferStat_Transfer && !readError && !writeError)
     {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] can't start transfert at Transfer"));
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] can't start transfert at Transfer due to transfer_stat==TransferStat_Transfer (double start?)"));
         return;
     }
-    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start"));
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] start")+", transfert id: "+std::to_string(transferId));
     if(canStartTransfer)
     {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] canStartTransfer is already set to true"));
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] canStartTransfer is already set to true")+", transfert id: "+std::to_string(transferId)+", transfer_stat: "+std::to_string((int)transfer_stat));
         // call for second time, first time was not ready, if blocked in preop why?
         //ifCanStartTransfer();
-        return;
+        //return;-> try call again, protected by if(transfer_stat!=TransferStat_WaitForTheTransfer /*wait preoperation*/ || !canStartTransfer/*wait start call*/) into ifCanStartTransfer()
     }
     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+("] check how start the transfer"));
     canStartTransfer=true;
@@ -298,6 +294,11 @@ void TransferThreadAsync::preOperation()
                                  TransferThread::internalStringTostring(source)+" than "+TransferThread::internalStringTostring(destination));
         return;
     }
+
+    //this case is used only on retry after error
+    readThread.stop();
+    writeThread.stop();
+
     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] after is same");
     /*Why this code?
     if(readError)
@@ -308,7 +309,7 @@ void TransferThreadAsync::preOperation()
     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] before destination exists");
     if(destinationExists())
     {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] destination exists: "+TransferThread::internalStringTostring(destination));
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] destination exists: "+TransferThread::internalStringTostring(destination)+", alwaysDoFileExistsAction: "+std::to_string((int)alwaysDoFileExistsAction));
         return;
     }
     ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] after destination exists");
@@ -337,6 +338,7 @@ void TransferThreadAsync::preOperation()
             ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] unable to read the source time: "+TransferThread::internalStringTostring(source));
             if(keepDate)
             {
+                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"!doTheDateTransfer && keepDate");
                 emit errorOnFile(source,tr("Wrong modification date or unable to get it, you can disable time transfer to do it").toStdString());
                 return;
             }
@@ -392,6 +394,12 @@ void TransferThreadAsync::setProgression(const uint64_t &pos, const uint64_t &si
             emit readStopped();
         transferProgression=pos;
     }
+    else
+    {
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"["+std::to_string(id)+
+                             "] transfer_stat:"+std::to_string(transfer_stat)+
+                             ", canStartTransfer: "+std::to_string(canStartTransfer)+", transfert id: "+std::to_string(transferId));
+    }
 }
 #endif
 
@@ -409,7 +417,7 @@ void TransferThreadAsync::ifCanStartTransfer()
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Information,"["+std::to_string(id)+
                                  "] transfer_stat:"+std::to_string(transfer_stat)+
-                                 ", canStartTransfer: "+std::to_string(canStartTransfer));
+                                 ", canStartTransfer: "+std::to_string(canStartTransfer)+", transfert id: "+std::to_string(transferId));
         //preOperationStopped();//tiger to seam maybe is can be started, maybe this generate a bug
         return;
     }
@@ -475,8 +483,9 @@ void TransferThreadAsync::ifCanStartTransfer()
     writeError=false;
     if(realMove)
     {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] start real move");
-        successFull=TransferThread::rename(source,destination);
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+"] start real move, source "+TransferThread::internalStringTostring(source)+" exists: "+std::to_string(TransferThread::exists(source)));
+        if(TransferThread::exists(source))
+            successFull=TransferThread::rename(source,destination);
         #ifdef Q_OS_UNIX
         if(!successFull && errno==18)
         {
@@ -667,6 +676,7 @@ void TransferThreadAsync::ifCanStartTransfer()
             #ifdef Q_OS_WIN32
             if(native_copy)
             {
+                ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,internalStringTostring(source)+" to "+internalStringTostring(destination)+": native_copy enabled");
                 successFull=CopyFileExW(TransferThread::toFinalPath(source).c_str(),TransferThread::toFinalPath(destination).c_str(),
                     (LPPROGRESS_ROUTINE)progressRoutine,this,&stopItWin,COPY_FILE_ALLOW_DECRYPTED_DESTINATION | 0x00000800);//0x00000800 is COPY_FILE_COPY_SYMLINK
                 if(successFull==FALSE)
@@ -717,12 +727,19 @@ void TransferThreadAsync::ifCanStartTransfer()
         #ifdef Q_OS_WIN32
         readError=true;
         writeError=true;
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"!successFull");
         emit errorOnFile(destination,strError);
         #else
         if(readError)
+        {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"!successFull on read");
             emit errorOnFile(source,strError);
+        }
         else
+        {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"!successFull on write");
             emit errorOnFile(destination,strError);
+        }
         #endif
         return;
     }
@@ -746,22 +763,29 @@ void TransferThreadAsync::checkIfAllIsClosedAndDoOperations()
     }
     if(!source.empty() && needRemove && (stopIt || needSkip))
         if(is_file(source) && source!=destination)
+        {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"remove because: is_file(source): "+std::to_string(is_file(source))+", source: "+TransferThread::internalStringTostring(source));
             unlink(destination);
+        }
     transfer_stat=TransferStat_Idle;
 
     transferSize=readThread.getLastGoodPosition();
 
     if(mode==Ultracopier::Move && !realMove)
+    {
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"["+std::to_string(id)+"] remove mode==Ultracopier::Move && !realMove: "+
+                                 TransferThread::internalStringTostring(source));
         if(exists(destination))
             if(!unlink(source))
                 ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"["+std::to_string(id)+"] move and unable to remove: "+
-                                         TransferThread::internalStringTostring(source)+
+                                         TransferThread::internalStringTostring(source)+std::string(" ")+
                          #ifdef Q_OS_WIN32
                                          GetLastErrorStdStr()
                          #else
                                          strerror(errno)
                          #endif
                                          );
+    }
     transfer_stat=TransferStat_PostTransfer;
     emit pushStat(transfer_stat,transferId);
     transfer_stat=TransferStat_PostOperation;
@@ -808,52 +832,6 @@ void TransferThreadAsync::stop()
     writeThread.stop();
 }
 
-//retry after error
-void TransferThreadAsync::retryAfterError()
-{
-    /// \warning skip the resetExtraVariable(); to be more exact and resolv some bug
-    if(transfer_stat==TransferStat_Idle)
-    {
-        if(transferId==0)
-        {
-            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+
-                                     ("] seam have bug, source: ")+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination));
-            return;
-        }
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+
-                                 "] restart all, source: "+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination));
-        readError=false;
-        //writeError=false;
-        emit internalStartPreOperation();
-        return;
-    }
-    //opening error
-    if(transfer_stat==TransferStat_PreOperation)
-    {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+
-                                 "] is not idle, source: "+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination)+
-                                 ", stat: "+std::to_string(transfer_stat));
-        readError=false;
-        //writeError=false;
-        emit internalStartPreOperation();
-        //tryOpen();-> recheck all, because can be an error into isSame(), rename(), ...
-        return;
-    }
-    //data streaming error
-    if(transfer_stat!=TransferStat_PostOperation && transfer_stat!=TransferStat_Transfer && transfer_stat!=TransferStat_PostTransfer)
-    {
-        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] is not in right stat, source: ")+
-                                 TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination)+", stat: "+std::to_string(transfer_stat));
-        return;
-    }
-    if(transfer_stat==TransferStat_PostOperation)
-    {
-        emit internalStartPostOperation();
-        return;
-    }
-    emit internalTryStartTheTransfer();
-}
-
 //skip the copy
 void TransferThreadAsync::skip()
 {
@@ -979,9 +957,22 @@ int64_t TransferThreadAsync::copiedSize()
     switch(static_cast<TransferStat>(transfer_stat))
     {
     case TransferStat_Transfer:
+        if(transferProgression>0)//then native copy started, read/write thread not used
+            return transferProgression;
+        else
+            return (readThread.getLastGoodPosition()+writeThread.getLastGoodPosition())/2;
+        break;
     case TransferStat_PostOperation:
+        if(transferProgression>0)//then native copy started, read/write thread not used
+            return transferSize;
+        else
+            return (readThread.getLastGoodPosition()+writeThread.getLastGoodPosition())/2;
+        break;
     case TransferStat_PostTransfer:
-        return (readThread.getLastGoodPosition()+writeThread.getLastGoodPosition())/2;
+        if(transferProgression>0)//then native copy started, read/write thread not used
+            return transferProgression;
+        else
+            return (readThread.getLastGoodPosition()+writeThread.getLastGoodPosition())/2;
     default:
         return 0;
     }
@@ -1066,14 +1057,17 @@ char TransferThreadAsync::writingLetter() const
 //not copied size, ...
 uint64_t TransferThreadAsync::realByteTransfered() const
 {
-    const uint64_t &l=readThread.getLastGoodPosition();
     switch(static_cast<TransferStat>(transfer_stat))
     {
     case TransferStat_Transfer:
+        if(transferProgression>0)//then native copy started, read/write thread not used
+            return transferProgression;
+        else
+            return readThread.getLastGoodPosition();
     case TransferStat_PostTransfer:
-        return l;
+        return readThread.getLastGoodPosition();
     case TransferStat_PostOperation:
-        return l;
+        return readThread.getLastGoodPosition();
     default:
         return 0;
     }
@@ -1086,8 +1080,16 @@ std::pair<uint64_t, uint64_t> TransferThreadAsync::progression() const
     switch(static_cast<TransferStat>(transfer_stat))
     {
     case TransferStat_Transfer:
-        returnVar.first=readThread.getLastGoodPosition();
-        returnVar.second=writeThread.getLastGoodPosition();
+        if(transferProgression>0)//then native copy started, read/write thread not used
+        {
+            returnVar.first=transferProgression;
+            returnVar.second=transferProgression;
+        }
+        else
+        {
+            returnVar.first=readThread.getLastGoodPosition();
+            returnVar.second=writeThread.getLastGoodPosition();
+        }
         /*if(returnVar.first<returnVar.second)
             ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Warning,"["+std::to_string(id)+QStringLiteral("] read is smaller than write"));*/
     break;
@@ -1109,6 +1111,11 @@ std::pair<uint64_t, uint64_t> TransferThreadAsync::progression() const
 }
 
 void TransferThreadAsync::setFileExistsAction(const FileExistsAction &action)
+{
+    emit setFileExistsActionSend(action);
+}
+
+void TransferThreadAsync::setFileExistsActionInternal(const FileExistsAction &action)
 {
     if(transfer_stat!=TransferStat_PreOperation)
     {
@@ -1249,7 +1256,12 @@ void TransferThreadAsync::read_error()
     readError		= true;
     //writeIsReadyVariable	= false;//wrong because write can be ready here
     if(!writeError)//already display error for the write
+    {
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"read error && !writeError");
         emit errorOnFile(source,readThread.errorString());
+    }
+    else
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"read error && writeError");
 }
 
 void TransferThreadAsync::read_readIsStopped()
@@ -1447,3 +1459,70 @@ void TransferThreadAsync::setNativeCopy(bool native_copy)
 {
     this->native_copy=native_copy;
 }
+
+//////////////////////////////////////////////////////////////////
+/////////////////////// Error management /////////////////////////
+//////////////////////////////////////////////////////////////////
+
+void TransferThreadAsync::retryAfterError()
+{
+    /// \warning skip the resetExtraVariable(); to be more exact and resolv some bug
+    if(transfer_stat==TransferStat_Idle)
+    {
+        if(transferId==0)
+        {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+
+                                     ("] seam have bug, source: ")+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination));
+            return;
+        }
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+
+                                 "] restart all, source: "+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination));
+        readError=false;
+        //writeError=false;
+        emit internalStartPreOperation();
+        return;
+    }
+    //opening error
+    if(transfer_stat==TransferStat_PreOperation)
+    {
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+
+                                 "] is not idle, source: "+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination)+
+                                 ", stat: "+std::to_string(transfer_stat));
+        readError=false;
+        writeError=false;//why was commented?
+        emit internalStartPreOperation();
+        //tryOpen();-> recheck all, because can be an error into isSame(), rename(), ...
+        return;
+    }
+    //data streaming error
+    if(transfer_stat!=TransferStat_PostOperation && transfer_stat!=TransferStat_Transfer && transfer_stat!=TransferStat_PostTransfer)
+    {
+        ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Critical,"["+std::to_string(id)+("] is not in right stat, source: ")+
+                                 TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination)+", stat: "+std::to_string(transfer_stat));
+        return;
+    }
+    if(transfer_stat==TransferStat_PostOperation)
+    {
+        emit internalStartPostOperation();
+        return;
+    }
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"["+std::to_string(id)+
+                             "] retryAfterError, source: "+TransferThread::internalStringTostring(source)+", destination: "+TransferThread::internalStringTostring(destination));
+
+    /*try restart from 0
+    * This is simplest way
+    * Simple mean less bug
+    * Allow restart with native copy
+    * More data check
+    * Yes it's less efficient, on failed on source, if after close/reopen the size is same, can be resumed where it stop
+    * */
+    //emit internalTryStartTheTransfer(); -> wrong in version 2
+    resetExtraVariable();
+    /*included into resetExtraVariable()
+    writeIsOpenVariable=false;
+    readError=false;
+    writeError=false;*/
+    transfer_stat=TransferStat_PreOperation;
+    writeThread.flushBuffer();
+    emit internalStartPreOperation();
+}
