@@ -6,7 +6,7 @@
     <message>
         <location filename="../../OptionsWidget.ui" line="17"/>
         <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
-        <translation>Im Normalfall ist für 32 oder 64-Bit-Beriebsysteme nur die jeweilige dll wichtig. Die UAC kann geöffnet werden um die dll zu laden.</translation>
+        <translation>Im Normalfall ist für 32 oder 64-Bit-Beriebsysteme nur die jeweilige DLL wichtig. Möglicherweise muss die Windows UAC bestätigt werden, um die DLL zu laden.</translation>
     </message>
     <message>
         <location filename="../../OptionsWidget.ui" line="20"/>
@@ -17,7 +17,7 @@
     <message>
         <location filename="../../OptionsWidget.ui" line="34"/>
         <source>Register for all users</source>
-        <translation type="unfinished"></translation>
+        <translation>Für alle Benutzer registrieren</translation>
     </message>
 </context>
 </TS>
