@@ -13,5 +13,10 @@
         <source>All the dlls are importants</source>
         <translation>Todas las dlls son importantes</translation>
     </message>
+    <message>
+        <location filename="../../OptionsWidget.ui" line="34"/>
+        <source>Register for all users</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
