@@ -6,17 +6,17 @@
     <message>
         <location filename="../../OptionsWidget.ui" line="+17"/>
         <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">일반적으로 64bit OS에서는 dll 64bit, 32bit OS에서는 32bit dll만 중요합니다. 특별히 중요한 경우, UAC를 열어 dll을 불러올 수 있습니다.</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>All the dlls are importants</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">모든 dll 중요 (32/64bit 모두)</translation>
     </message>
     <message>
         <location line="+14"/>
         <source>Register for all users</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">모든 사용자에 대해 등록</translation>
     </message>
 </context>
 </TS>
