@@ -4,61 +4,61 @@
 <context>
     <name>Themes</name>
     <message>
-        <location filename="../../interface.cpp" line="328"/>
+        <location filename="../../interface.cpp" line="341"/>
         <source>Buy the Ultimate version to fund development</source>
         <translation>Kaufe die Ultimate Version um die Entwicklung zu finanzieren</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="328"/>
+        <location filename="../../interface.cpp" line="341"/>
         <source>Register your key</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="427"/>
+        <location filename="../../interface.cpp" line="440"/>
         <source>File %1/%2, size: %3/%4</source>
         <translation>Datei %1/%2, Größe:%3/%4</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="661"/>
+        <location filename="../../interface.cpp" line="674"/>
         <source>Copy list</source>
         <translation>Zu kopierende Dateien</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="663"/>
+        <location filename="../../interface.cpp" line="676"/>
         <source>Move list</source>
         <translation>Zu verschiebende Dateien</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1091"/>
+        <location filename="../../interface.cpp" line="1117"/>
         <source>Don&apos;t close if errors are found</source>
         <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1092"/>
+        <location filename="../../interface.cpp" line="1118"/>
         <source>Never close</source>
         <translation>Niemals schließen</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1093"/>
+        <location filename="../../interface.cpp" line="1119"/>
         <source>Always close</source>
         <translation>Immer schließen</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1095"/>
+        <location filename="../../interface.cpp" line="1121"/>
         <source>File Name, 0KB</source>
         <translation>Dateiname, 0KB</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1289"/>
-        <location filename="../../interface.cpp" line="1301"/>
-        <location filename="../../interface.cpp" line="1313"/>
+        <location filename="../../interface.cpp" line="1395"/>
+        <location filename="../../interface.cpp" line="1407"/>
+        <location filename="../../interface.cpp" line="1419"/>
         <source>Select a color</source>
         <translation>Farbe auswählen</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1388"/>
-        <location filename="../../interface.cpp" line="1392"/>
-        <location filename="../../interface.cpp" line="1394"/>
+        <location filename="../../interface.cpp" line="1494"/>
+        <location filename="../../interface.cpp" line="1498"/>
+        <location filename="../../interface.cpp" line="1500"/>
         <source>%1 %2% of %3</source>
         <translation>%1 %2% von %3</translation>
     </message>
@@ -66,24 +66,24 @@
 <context>
     <name>ThemesFactory</name>
     <message>
-        <location filename="../../ThemesFactory.cpp" line="284"/>
+        <location filename="../../ThemesFactory.cpp" line="294"/>
         <source>Don&apos;t close if errors are found</source>
         <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
     </message>
     <message>
-        <location filename="../../ThemesFactory.cpp" line="285"/>
+        <location filename="../../ThemesFactory.cpp" line="295"/>
         <source>Never close</source>
         <translation>Niemals schließen</translation>
     </message>
     <message>
-        <location filename="../../ThemesFactory.cpp" line="286"/>
+        <location filename="../../ThemesFactory.cpp" line="296"/>
         <source>Always close</source>
         <translation>Immer schließen</translation>
     </message>
     <message>
-        <location filename="../../ThemesFactory.cpp" line="482"/>
-        <location filename="../../ThemesFactory.cpp" line="497"/>
-        <location filename="../../ThemesFactory.cpp" line="512"/>
+        <location filename="../../ThemesFactory.cpp" line="510"/>
+        <location filename="../../ThemesFactory.cpp" line="525"/>
+        <location filename="../../ThemesFactory.cpp" line="540"/>
         <source>Select a color</source>
         <translation>Wählen Sie eine Farbe</translation>
     </message>
@@ -250,7 +250,7 @@
 <context>
     <name>themesOptions</name>
     <message>
-        <location filename="../../themesOptions.ui" line="267"/>
+        <location filename="../../themesOptions.ui" line="402"/>
         <source>Show dual progression</source>
         <translation></translation>
     </message>
@@ -291,7 +291,12 @@
         <translation>Minimiert starten</translation>
     </message>
     <message>
-        <location filename="../../themesOptions.ui" line="306"/>
+        <location filename="../../themesOptions.ui" line="213"/>
+        <source>Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../themesOptions.ui" line="269"/>
         <source>Click to edit the color</source>
         <translation>Zum Bearbeiten der Farbe klicken</translation>
     </message>
@@ -305,31 +310,36 @@
         <source>Save position</source>
         <translation>Speichere Fensterposition</translation>
     </message>
-    <message>
-        <location filename="../../themesOptions.ui" line="213"/>
-        <source>Informations</source>
-        <translation>Informationen</translation>
-    </message>
     <message>
         <location filename="../../themesOptions.ui" line="251"/>
         <source>Display</source>
         <translation>Anzeige</translation>
     </message>
     <message>
-        <location filename="../../themesOptions.ui" line="257"/>
+        <location filename="../../themesOptions.ui" line="368"/>
         <source>Speed with progress bar</source>
         <translation>Geschwindigkeit als Fortschrittsbalken anzeigen</translation>
     </message>
     <message>
-        <location filename="../../themesOptions.ui" line="287"/>
+        <location filename="../../themesOptions.ui" line="378"/>
         <source>Progression color</source>
         <translation>Farbe des Fortschrittsbalken</translation>
     </message>
     <message>
-        <location filename="../../themesOptions.ui" line="277"/>
+        <location filename="../../themesOptions.ui" line="388"/>
         <source>Show progression in the title</source>
         <translation>Fortschritt im Fenstertitel zeigen</translation>
     </message>
+    <message>
+        <location filename="../../themesOptions.ui" line="395"/>
+        <source>General margin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../themesOptions.ui" line="425"/>
+        <source>General spacing</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../themesOptions.ui" line="183"/>
         <source>Always on top</source>
