@@ -19,6 +19,9 @@
     #endif
     #include <windows.h>
 #endif
+#ifdef ULTRACOPIER_PLUGIN_DEBUG
+#include <sys/stat.h>
+#endif
 
 #include "interface.h"
 #include "ui_interface.h"
@@ -56,7 +59,9 @@ Themes::Themes(const bool &alwaysOnTop,
                const bool &moreButtonPushed,
                const bool &minimizeToSystray,
                const bool &startMinimized,
-               const bool &savePosition) :
+               const bool &savePosition,
+               const qint8 &generalMargin,
+               const qint8 &generalSpacing) :
     duration(0),
     durationStarted(false),
     ui(new Ui::interfaceCopy()),
@@ -105,6 +110,8 @@ Themes::Themes(const bool &alwaysOnTop,
     uiOptions->showDualProgression->setChecked(showDualProgression);
     uiOptions->startMinimized->setEnabled(false);
     uiOptions->alwaysOnTop->setChecked(alwaysOnTop);
+    uiOptions->generalMargin->setValue(generalMargin);
+    uiOptions->generalSpacing->setValue(generalSpacing);
     uiOptions->minimizeToSystray->setChecked(minimizeToSystray);
     //uiOptions->setupUi(ui->tabWidget->widget(ui->tabWidget->count()-1));
     uiOptions->labelStartWithMoreButtonPushed->setVisible(false);
@@ -133,6 +140,9 @@ Themes::Themes(const bool &alwaysOnTop,
     uiOptions->checkBoxShowSpeed->setChecked(checkBoxShowSpeed);
     menu=new QMenu(this);
     ui->add->setMenu(menu);
+    ui->interfaceLayout->setSpacing(uiOptions->generalSpacing->value());
+    const quint8 &margin=uiOptions->generalMargin->value();
+    ui->interfaceLayout->setContentsMargins(margin, margin, margin, margin);
 
     //connect the options
     checkBoxShowSpeed_toggled(uiOptions->checkBoxShowSpeed->isChecked());
@@ -145,11 +155,14 @@ Themes::Themes(const bool &alwaysOnTop,
     connect(uiOptions->progressColorRemaining,&QAbstractButton::clicked,this,&Themes::progressColorRemaining_clicked);
     connect(uiOptions->alwaysOnTop,&QAbstractButton::clicked,this,&Themes::alwaysOnTop_clickedSlot);
 
-    isInPause(false);
-
     connect(uiOptions->limitSpeed,		static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),	this,	&Themes::uiUpdateSpeed);
     connect(uiOptions->checkBox_limitSpeed,&QAbstractButton::toggled,		this,	&Themes::uiUpdateSpeed);
 
+    isInPause(false);
+
+    connect(uiOptions->generalMargin,		static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),	this,	&Themes::uigeneralMargin);
+    connect(uiOptions->generalSpacing,		static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged),	this,	&Themes::uigeneralSpacing);
+
     connect(ui->actionAddFile,&QAction::triggered,this,&Themes::forcedModeAddFile);
     connect(ui->actionAddFileToCopy,&QAction::triggered,this,&Themes::forcedModeAddFileToCopy);
     connect(ui->actionAddFileToMove,&QAction::triggered,this,&Themes::forcedModeAddFileToMove);
@@ -537,7 +550,7 @@ void Themes::detectedSpeed(const uint64_t &speed)//in byte per seconds
             tempSpeed=999999999;
         if(tempSpeed>(quint64)ui->progressBarCurrentSpeed->maximum())
         {
-            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"set max speed to: "+std::to_string(tempSpeed));
+            //ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"set max speed to: "+std::to_string(tempSpeed));
             ui->progressBarCurrentSpeed->setMaximum(tempSpeed);
         }
         ui->progressBarCurrentSpeed->setValue(tempSpeed);
@@ -917,6 +930,19 @@ void Themes::uiUpdateSpeed()
     emit newSpeedLimitation(currentSpeed);
 }
 
+void Themes::uigeneralSpacing()
+{
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"emit uigeneralSpacing"+std::to_string(uiOptions->generalSpacing->value()));
+    ui->interfaceLayout->setSpacing(uiOptions->generalSpacing->value());
+}
+
+void Themes::uigeneralMargin()
+{
+    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"emit uigeneralMargin"+std::to_string(uiOptions->generalMargin->value()));
+    const quint8 &margin=uiOptions->generalMargin->value();
+    ui->interfaceLayout->setContentsMargins(margin, margin, margin, margin);
+}
+
 void Themes::updateSpeed()
 {
     ui->label_Slider_speed->setVisible(uiOptions->checkBoxShowSpeed->isChecked());
@@ -1210,6 +1236,26 @@ void Themes::on_moreButton_toggled(bool checked)
     this->adjustSize();
 }
 
+#ifdef ULTRACOPIER_PLUGIN_DEBUG
+bool stringStartWithInter(std::string const &fullString, std::string const &starting)
+{
+    if (fullString.length() >= starting.length()) {
+        return (fullString.substr(0,starting.length())==starting);
+    } else {
+        return false;
+    }
+}
+
+#ifdef WIDESTRING
+#define INTERNALTYPEPATH std::wstring
+#define INTERNALTYPECHAR wchar_t
+#else
+#define INTERNALTYPEPATH std::string
+#define INTERNALTYPECHAR char
+#endif
+
+#endif
+
 /* drag event processing
 
 need setAcceptDrops(true); into the constructor
@@ -1224,6 +1270,13 @@ void Themes::dropEvent(QDropEvent *event)
     const QMimeData* mimeData = event->mimeData();
     if(mimeData->hasUrls())
     {
+        if(event->dropAction()!=Qt::CopyAction)
+        {
+            ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"event->dropAction()!=Qt::CopyAction ignore");
+            //drag'n'drop with shift pressed send the file to trash
+            event->ignore();
+            return;
+        }
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"hasUrls");
         std::vector<std::string> urls;
         unsigned int index=0;
@@ -1235,6 +1288,51 @@ void Themes::dropEvent(QDropEvent *event)
             urls.push_back(urlString);
             index++;
         }
+
+        #ifdef ULTRACOPIER_PLUGIN_DEBUG
+        {
+
+            unsigned int index=0;
+            while(index<urls.size())
+            {
+                std::string source=urls.at(index);
+                //can be: file://192.168.0.99/share/file.txt
+                //can be: file:///C:/file.txt
+                //can be: file:///home/user/fileatrootunderunix
+                #ifndef Q_OS_WIN
+                if(stringStartWithInter(source,"file:///"))
+                    source.replace(0,7,"");
+                #else
+                if(stringStartWithInter(source,"file:///"))
+                    source.replace(0,8,"");
+                else if(stringStartWithInter(source,"file://"))
+                    source.replace(0,5,"");
+                else if(stringStartWithInter(source,"file:/"))
+                    source.replace(0,6,"");
+                #endif
+                if(index<99)
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,urls.at(index)+" -> "+source);
+                index++;
+
+                #ifndef __WIN32__
+                struct stat sb;
+                if (::stat(source.c_str(), &sb) == -1)
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"source is_file: 0");
+                else
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"source is_file: 1");
+                #else
+                DWORD dwAttrib = GetFileAttributesA(source.c_str());
+                if(dwAttrib != INVALID_FILE_ATTRIBUTES &&
+                        (dwAttrib & FILE_ATTRIBUTE_NORMAL || dwAttrib & FILE_ATTRIBUTE_ARCHIVE)
+                         )
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"source is_file: 1");
+                else
+                    ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"source is_file: 0");
+                #endif
+            }
+        }
+        #endif
+
         emit urlDropped(urls);
         event->acceptProposedAction();
     }
@@ -1248,7 +1346,10 @@ void Themes::dragEnterEvent(QDragEnterEvent* event)
     if(mimeData->hasUrls())
     {
         ULTRACOPIER_DEBUGCONSOLE(Ultracopier::DebugLevel_Notice,"hasUrls");
-        event->acceptProposedAction();
+        if(event->dropAction()==Qt::CopyAction)
+            event->acceptProposedAction();
+        else
+            event->ignore();//drag'n'drop with shift pressed send the file to trash
     }
 }
 
@@ -1257,7 +1358,12 @@ void Themes::dragMoveEvent(QDragMoveEvent* event)
     // if some actions should not be usable, like move, this code must be adopted
     const QMimeData* mimeData = event->mimeData();
     if(mimeData->hasUrls())
-        event->acceptProposedAction();
+    {
+        if(event->dropAction()==Qt::CopyAction)
+            event->acceptProposedAction();
+        else
+            event->ignore();//drag'n'drop with shift pressed send the file to trash
+    }
 }
 
 void Themes::dragLeaveEvent(QDragLeaveEvent* event)
