@@ -8,19 +8,27 @@
         <source>%1 files</source>
         <translation>%1 Dateien</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location filename="../../radialMap/map.cpp" line="204"/>
-        <source>%1 file, with an average size of %2</source>
-        <translation>%1 Datei, mit einer ungefähren Größe von %2</translation>
+        <source>%n file(s), with an average size of %1</source>
+        <comment>file</comment>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
 </context>
 <context>
     <name>RadialMap::Widget</name>
-    <message>
+    <message numerus="yes">
         <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
         <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
-        <source> into %1 files</source>
-        <translation> in%1 Dateien</translation>
+        <source> into %n file(s)</source>
+        <comment>file</comment>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -73,16 +81,16 @@
         <translation>Dateiname, 0KB</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1534"/>
-        <location filename="../../interface.cpp" line="1546"/>
-        <location filename="../../interface.cpp" line="1558"/>
+        <location filename="../../interface.cpp" line="1549"/>
+        <location filename="../../interface.cpp" line="1561"/>
+        <location filename="../../interface.cpp" line="1573"/>
         <source>Select a color</source>
         <translation>Farbe auswählen</translation>
     </message>
     <message>
-        <location filename="../../interface.cpp" line="1646"/>
-        <location filename="../../interface.cpp" line="1657"/>
-        <location filename="../../interface.cpp" line="1666"/>
+        <location filename="../../interface.cpp" line="1661"/>
+        <location filename="../../interface.cpp" line="1672"/>
+        <location filename="../../interface.cpp" line="1681"/>
         <source>%1 %2% of %3 into %4 files</source>
         <translation>%1 %2 von %3 in %4 Dateien</translation>
     </message>
@@ -324,6 +332,11 @@
         <source>Position at start</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../themesOptions.ui" line="239"/>
+        <source>Information</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../themesOptions.ui" line="332"/>
         <source>Click to edit the color</source>
@@ -354,11 +367,6 @@
         <source>At Center</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../themesOptions.ui" line="239"/>
-        <source>Informations</source>
-        <translation>Informationen</translation>
-    </message>
     <message>
         <location filename="../../themesOptions.ui" line="277"/>
         <source>Display</source>
